@@ -557,7 +557,7 @@ kaplanModule <- function(input, output, session, data, data_label, data_varStruc
                      }
 
                      if (input$file_ext == "emf"){
-                       devEMF::emf(file, width = input$fig_width, height = input$fig_height, coordDPI = 300)
+                       devEMF::emf(file, width = input$fig_width, height = input$fig_height, coordDPI = 300, emfPlus = F)
                        graphics::plot(kmInput())
                        grDevices::dev.off()
 
